@@ -76,7 +76,7 @@ class Userform(tornado.web.RequestHandler):
     async def get(self):
         log.write_logs("1a.", str(self.get_current_user()), "auth", f'{os.environ.get("ENVIRONMENT")}-logs')
         log.write_logs("1b.", str(self.get_argument('code', False)), "auth", f'{os.environ.get("ENVIRONMENT")}-logs')
-        if self.get_argument('code', False) and not self.get_current_user():
+        if not self.get_argument('code', False) and not self.get_current_user():
             log.write_logs("2.", str(self.get_argument('code', False)), "auth", f'{os.environ.get("ENVIRONMENT")}-logs')
             self.redirect("/login")
         elif self.get_argument('code', False):
